package
Version:
v0.0.0-...-a7b642f
Opens a new window with list of versions in this module.
Published: Dec 16, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type User_t struct {
gorm.Model
SignID string
PW string
Budget uint
WorkAddress Coordinate_t `gorm:"embedded"`
PreferedFac string
PreferedEnv CheckList_t `gorm:"embedded"`
Houses []House_t `gorm:"foreignKey:Owner"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.